@@ -24,9 +24,9 @@ author = "Egemen Imre"
 # Version Info
 # ------------
 # The short X.Y version.
-version = "0.0.3"
+version = "0.0.6"
 # The full version, including alpha/beta/rc tags.
-release = "0.0.3"
+release = "0.0.6"
 
 # -- General configuration ---------------------------------------------------
 # By default, highlight as Python 3.
@@ -63,8 +63,8 @@ master_doc = "index"
 # Intersphinx configuration
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3", None),
-    "astropy": ("http://docs.astropy.org/en/stable/", None),
-    "numpy": ("https://docs.scipy.org/doc/numpy/", None),
+    "astropy": ("https://docs.astropy.org/en/stable/", None),
+    "numpy": ("https://numpy.org/doc/stable/", None),
     "scipy": ("https://docs.scipy.org/doc/scipy/reference", None),
     "matplotlib": ("https://matplotlib.org", None),
 }
@@ -75,7 +75,7 @@ else:
     nbsphinx_execute = "always"
 
 # Controls when a cell will time out (defaults to 30; use -1 for no timeout):
-nbsphinx_timeout = 60
+nbsphinx_timeout = 1000
 
 # -- Options for HTML output -------------------------------------------------
 
